pika Transport - kombu.transport.pypika — Kombu v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »

# pika Transport - kombu.transport.pypika

class `kombu.transport.pypika.` `AsyncoreConnection`(parameters, wait_for_open=True, reconnection_strategy=None)
  `channel`()

class `kombu.transport.pypika.` `AsyncoreTransport`(client, **kwargs)
  `Connection`

    alias of `AsyncoreConnection`

class `kombu.transport.pypika.` `BlockingConnection`(parameters, wait_for_open=True, reconnection_strategy=None)
  `channel`()

class `kombu.transport.pypika.` `Channel`(handler)
  class `Message`(channel, amqp_message, **kwargs)
  `Channel.` `basic_ack`(delivery_tag)
  `Channel.` `basic_consume`(queue, no_ack=False, consumer_tag=None, callback=None, nowait=False)
  `Channel.` `basic_get`(queue, no_ack)
  `Channel.` `basic_publish`(message, exchange, routing_key, mandatory=False, immediate=False)
  `Channel.` `message_to_python`(raw_message)

    Convert encoded message body back to a Python value.

  `Channel.` `prepare_message`(message_data, priority=None, content_type=None, content_encoding=None, headers=None, properties=None)

    Encapsulate data into a AMQP message.

class `kombu.transport.pypika.` `Message`(channel, amqp_message, **kwargs)

class `kombu.transport.pypika.` `SyncTransport`(client, **kwargs)
  `Connection`

    alias of `BlockingConnection`

  class `Message`(channel, amqp_message, **kwargs)
  `SyncTransport.` `close_connection`(connection)

    Close the AMQP broker connection.

  `SyncTransport.` `create_channel`(connection)
  `SyncTransport.` `drain_events`(connection, **kwargs)
  `SyncTransport.` `establish_connection`()

    Establish connection to the AMQP broker.

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »